#
# spec file for package python-pyglet
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         X_display         ":98"
# TODO: Can't get display working with glx
%bcond_with     test
Name:           python-pyglet
Version:        1.3.1
Release:        lp150.1.2
Summary:        Windowing and multimedia library
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://bitbucket.org/pyglet/pyglet
Source0:        https://files.pythonhosted.org/packages/source/p/pyglet/pyglet-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE pyglet-1.2.4-fix-image-import.patch -- fix "import Image"
Patch0:         pyglet-1.2.4-fix-image-import.patch
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  alsa-devel
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  gtk2-devel
BuildRequires:  openal-soft-devel
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(x11)
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  config(Mesa)
BuildRequires:  xorg-x11-server
%endif
Requires:       alsa-devel
Requires:       fontconfig-devel
Requires:       freetype2-devel
Requires:       gtk2-devel
Requires:       openal-soft-devel
Requires:       python-Pillow
Requires:       config(Mesa)
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(x11)
BuildArch:      noarch

%python_subpackages

%description
Pyglet provides an object-oriented programming interface for
developing games and other visually-rich applications.

%prep
%setup -q -n pyglet-%{version}
%patch0
# Can't be used for commercial purposes
rm -r examples/noisy/

# Convert to unix line end
find -name "*.py" -exec dos2unix "{}" "+"

%build
%python_build

%install
%python_install

%{python_expand cp -Lr examples examples_%{$python_bin_suffix}
find examples_%{$python_bin_suffix} -name "*.py" -exec sed -i "s|^#!/usr/bin/python$|#!%{__$python}|" {} \;
find examples_%{$python_bin_suffix} -name "*.py" -exec sed -i "s|^#!/usr/bin/env python$|#!%{__$python}|" {} \;
%fdupes examples_%{$python_bin_suffix}
%fdupes %{buildroot}%{$python_sitelib}
}

%if %{with test}
%check
#############################################
### Launch a virtual framebuffer X server ###
#############################################
export DISPLAY=%{X_display}
 vfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10
%python_expand py.test-%{$python_bin_suffix}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE NOTICE README RELEASE_NOTES
%doc examples_%{python_bin_suffix}
%{python_sitelib}/pyglet
%{python_sitelib}/pyglet-%{version}-py*.egg-info

%changelog
* Thu Feb 15 2018 toddrme2178@gmail.com
- Remove "noisy" example.  It can't be used for commercial purposes
* Wed Feb 14 2018 toddrme2178@gmail.com
- Update to version 1.3.1
  + Bugfixes
  * #158 Fix mouse events in mouse exclusive mode on Windows.
  * #105 Crashes in PulseAudio;
  * #163 Workaround for running inside Spyder;
  * #45  Expose viewport size for use on HiDPI screens;
  * #15  Respect keyboard layout on macOS;
- Update to version 1.3.0
  * The entire codebase is now compatible with both Python 2 and Python 3 without the need for 2to3.
  + New features
  * The procedural audio module is now more usable. This module allows synthesis of basic
    waveforms, such as sine, square, triangle, sawtooth, and simple FM (two operator sine).
    In addition, several basic amplitude envelopes are now available to apply to generated audio.
    These include ADSR, linear decay, tremolo, and flat envelopes.
  + Improvements
  * Improved font rendering for fonts with negative bearing (#99)
  * Sprites now have `scale_x` and `scale_y` attributes, allowing for aspect ratio changes. The
    existing `scale` attribute sets the overall scaling, and functions as before.
  * Sprites have a new `update` method which allows simultaneous changing of position, scale, and
    rotation. This reduces some overhead when changing multiple attributes at once.
  * The pyglet.resource module now defaults to a 2048x2048 texture for it's internal texture atlas,
    but will fall back to the maximum available size that the GPU can provide.
  * All modern joysticks and game controllers should now be detected on Linux and Windows.
  * Refactored and reimplemented pyglet.media. Many improvements to stability. Different drivers
    should now behave more similar.
  * WM_CLASS hints are now set on Linux. On modern Linux desktop environments and window managers,
    this allows for proper tracking of pyglet applications. Previously, pyglet apps may show up as
    "Unknown" under the active window list in the environment. The window class hints are set
    to the same name as the Window caption, but will fall back to "pyglet" if the Window caption
    contains non-ascii characters.
  * Vastly improved documentation and programming guide.
  + Bugfixes
  * Limit the minimum window size 1x1 pixel, preventing an OpenGL exception when resizing (#49).
  * Font module no longer leaks memory when text is changed (#66).
  * Fix crash on Python 2 when sys.argv[0] has non-ASCII characters (#74).
  * Windows: Fix crash when opening multiple windows in succession (#81).
  * Windows: Fix local font loading (#100).
  * Windows: Italic fonts no longer render parts of their neighbors.
  * Prevent memory leak from orphaned StreamingSources in long running applications (#103).
  * Windows: Fix kerning regression (#115)
  * Windows: Window.set_icon no longer fails when given a Texture instead of ImageData (#136)
- Remove upstream-included pyglet-1.2.4-add-wmclass.patch
* Sun Aug 13 2017 toddrme2178@gmail.com
- Remove obsolete python-imaging dependency
* Tue Aug  8 2017 jengelh@inai.de
- Other OS need not be mentioned in description for an openSUSE
  package.
* Mon Aug  7 2017 toddrme2178@gmail.com
- Further fix shebangs
- Remove pyglet-1.2.4-fix-examples.patch
  We will fix shebangs dynamically
* Sun Aug  6 2017 toddrme2178@gmail.com
- Implement single-spec version
* Mon Jul 31 2017 kkirill@opensuse.org
- Add pyglet-1.2.4-fix-image-import.patch to fix "import Image"
- Add pyglet-1.2.4-add-wmclass.patch to add WMClass
- Add pyglet-1.2.4-fix-examples.patch to fix python shebang
* Thu Sep  3 2015 nemysis@openSUSE.org
- Update to 1.2.4, announce message:
  Bugfixes:
  - X11: Fix ContextException due to negative return value (#51)
  - X11: Fix segmentation fault in GdkPixBuf (#50)
  - OpenAL: Fix incompatibility with Python 3 (#57)
* Fri Aug 21 2015 nemysis@openSUSE.org
- Update to 1.2.3
  Many bugfixes, please look
  /usr/share/doc/packages/python-pyglet/CHANGELOG and RELEASE_NOTES
- Change URL
- Use %%{oname} instead of pyglet
- Add --rpmlintrc, for false positive needed scripts in datadir
  and documentation, not a devel package
- Add BuildRequires for fdupes and use %%fdupes macro to reduce size of the package
- Add BuildRequires for dos2unix and python-setuptools
- Change Documentation
* Fri May 10 2013 toddrme2178@gmail.com
- Build doc
- Add dependencies
* Fri May 10 2013 toddrme2178@gmail.com
- Initial version
